@@ -12,7 +12,7 @@ for frame in inspect.stack():
 if not called_from_setup:
 
     from EEETools.Tools.API.terminal_api import paste_default_excel_file, paste_components_documentation, paste_user_manual
-    from EEETools.Tools.API.terminal_api import calculate, launch_connection_debug, launch_network_display
+    from EEETools.Tools.API.terminal_api import calculate, launch_connection_debug, launch_network_display, plot_sankey
 
 else:
 
